import React, { useEffect } from "react";
import "./Overlay.css";
import { IOverlayProps } from "./Interface.type";

const Overlay: React.FC<IOverlayProps> = ({
  activeElementId,
  onClose,
  colorConfig,
}) => {
  useEffect(() => {
    if (activeElementId) {
      const activeElement = document.getElementById(activeElementId);

      if (activeElement) {
        activeElement.style.position = "absolute"; 
        activeElement.style.zIndex = "1000";
        activeElement.style.boxShadow = `0 0 10px ${colorConfig.highlightColor || "green"}`;
      }

      return () => {
        if (activeElement) {
          activeElement.style.position = "";
          activeElement.style.zIndex = "";
          activeElement.style.boxShadow = "";
        }
      };
    }
  }, [activeElementId, colorConfig.highlightColor]);

  return (
    <div
      className="fixed top-0 left-0 w-full h-full"
      style={{
        backgroundColor: colorConfig.overlayBackgroundColor || "rgba(0, 0, 0, 0.5)",
        zIndex: 999,
      }}
      onClick={onClose}
    />
  );
};

export default Overlay;
